Distillation
============
Perform a calculation for distillation of mixtures
of chemical compounds.

<p align="center"> 
    <img 
        src="distillation/column_diagram.png" 
        width="300"
    />
</p>

Currently only supports configurations with total condensers and partial reboilers.
Equilibrium data currently only comes from DePriester charts
and is assumed to only depend on pressure and temperature.


Documentation
=============
The online documentation can be found [here](https://dejac001.github.io/distillation).

Contributing
============
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.
